Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1574)

Unified Diff: pkg/scheduled_test/test/scheduled_server_test.dart

Issue 16123036: Clean up dart:io exceptions. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/scheduled_test/lib/src/scheduled_server/safe_http_server.dart ('k') | runtime/bin/dartutils.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/scheduled_test/test/scheduled_server_test.dart
diff --git a/pkg/scheduled_test/test/scheduled_server_test.dart b/pkg/scheduled_test/test/scheduled_server_test.dart
index ec08bb56d3c9c3dddf12a0d135ce4d5412f4bbf1..b4cd897eb666c5137f069336b75d56c6d67c0b06 100644
--- a/pkg/scheduled_test/test/scheduled_server_test.dart
+++ b/pkg/scheduled_test/test/scheduled_server_test.dart
@@ -38,16 +38,16 @@ void main() {
test('test 2', () {
expect(errors, everyElement(new isInstanceOf<ScheduleError>()));
// TODO(nweiz): There can be three errors due to issue 9151. The
// HttpParserException is reported without a stack trace, and so when it's
// wrapped twice it registers as a different exception each time (because
// it's given an ad-hoc stack trace). Always expect two exceptions when
// issue 9151 is fixed.
expect(errors.length, inInclusiveRange(2, 3));
expect(errors[0].error, equals("'scheduled server 0' received GET /hello "
"when no more requests were expected."));
- expect(errors[1].error, new isInstanceOf<HttpParserException>());
+ expect(errors[1].error, new isInstanceOf<HttpException>());
if (errors.length > 2) {
- expect(errors[2].error, new isInstanceOf<HttpParserException>());
+ expect(errors[2].error, new isInstanceOf<HttpException>());
}
});
}, passing: ['test 2']);
@@ -110,16 +110,16 @@ void main() {
test('test 2', () {
// TODO(nweiz): There can be three errors due to issue 9151. The
// HttpParserException is reported without a stack trace, and so when it's
// wrapped twice it registers as a different exception each time (because
// it's given an ad-hoc stack trace). Always expect two exceptions when
// issue 9151 is fixed.
expect(errors.length, inInclusiveRange(2, 3));
expect(errors[0].error, equals("'scheduled server 0' received GET /hello "
"earlier than expected."));
- expect(errors[1].error, new isInstanceOf<HttpParserException>());
+ expect(errors[1].error, new isInstanceOf<HttpException>());
if (errors.length > 2) {
- expect(errors[2].error, new isInstanceOf<HttpParserException>());
+ expect(errors[2].error, new isInstanceOf<HttpException>());
}
expect(errors, everyElement(new isInstanceOf<ScheduleError>()));
});
@@ -166,16 +166,16 @@ void main() {
test('test 2', () {
// TODO(nweiz): There can be three errors due to issue 9151. The
// HttpParserException is reported without a stack trace, and so when it's
// wrapped twice it registers as a different exception each time (because
// it's given an ad-hoc stack trace). Always expect two exceptions when
// issue 9151 is fixed.
expect(errors.length, inInclusiveRange(2, 3));
expect(errors[0].error, equals("'scheduled server 0' expected GET "
"/goodbye, but got GET /hello."));
- expect(errors[1].error, new isInstanceOf<HttpParserException>());
+ expect(errors[1].error, new isInstanceOf<HttpException>());
if (errors.length > 2) {
- expect(errors[2].error, new isInstanceOf<HttpParserException>());
+ expect(errors[2].error, new isInstanceOf<HttpException>());
}
});
}, passing: ['test 2']);
@@ -199,16 +199,16 @@ void main() {
test('test 2', () {
// TODO(nweiz): There can be three errors due to issue 9151. The
// HttpParserException is reported without a stack trace, and so when it's
// wrapped twice it registers as a different exception each time (because
// it's given an ad-hoc stack trace). Always expect two exceptions when
// issue 9151 is fixed.
expect(errors.length, inInclusiveRange(2, 3));
expect(errors[0].error, equals("'scheduled server 0' expected GET "
"/hello, but got HEAD /hello."));
- expect(errors[1].error, new isInstanceOf<HttpParserException>());
+ expect(errors[1].error, new isInstanceOf<HttpException>());
if (errors.length > 2) {
- expect(errors[2].error, new isInstanceOf<HttpParserException>());
+ expect(errors[2].error, new isInstanceOf<HttpException>());
}
});
}, passing: ['test 2']);
@@ -304,16 +304,16 @@ void main() {
test('test 2', () {
// TODO(nweiz): There can be three errors due to issue 9151. The
// HttpParserException is reported without a stack trace, and so when it's
// wrapped twice it registers as a different exception each time (because
// it's given an ad-hoc stack trace). Always expect two exceptions when
// issue 9151 is fixed.
expect(errors.length, inInclusiveRange(2, 3));
expect(errors[0].error, equals("'scheduled server 0' received GET "
"/hello/3 when no more requests were expected."));
- expect(errors[1].error, new isInstanceOf<HttpParserException>());
+ expect(errors[1].error, new isInstanceOf<HttpException>());
if (errors.length > 2) {
- expect(errors[2].error, new isInstanceOf<HttpParserException>());
+ expect(errors[2].error, new isInstanceOf<HttpException>());
}
});
}, passing: ['test 2']);
@@ -336,15 +336,15 @@ void main() {
test('test 2', () {
// TODO(nweiz): There can be three errors due to issue 9151. The
// HttpParserException is reported without a stack trace, and so when it's
// wrapped twice it registers as a different exception each time (because
// it's given an ad-hoc stack trace). Always expect two exceptions when
// issue 9151 is fixed.
expect(errors.length, inInclusiveRange(2, 3));
expect(errors[0].error, equals('oh no'));
- expect(errors[1].error, new isInstanceOf<HttpParserException>());
+ expect(errors[1].error, new isInstanceOf<HttpException>());
if (errors.length > 2) {
- expect(errors[2].error, new isInstanceOf<HttpParserException>());
+ expect(errors[2].error, new isInstanceOf<HttpException>());
}
});
}, passing: ['test 2']);
@@ -38,16 +38,16 @@ void main() {
expect(errors, everyElement(new isInstanceOf<ScheduleError>()));
// TODO(nweiz): There can be three errors due to issue 9151. The
- // HttpParserException is reported without a stack trace, and so when it's
+ // HttpException is reported without a stack trace, and so when it's
// wrapped twice it registers as a different exception each time (because
// it's given an ad-hoc stack trace). Always expect two exceptions when
@@ -110,16 +110,16 @@ void main() {
test('test 2', () {
// TODO(nweiz): There can be three errors due to issue 9151. The
- // HttpParserException is reported without a stack trace, and so when it's
+ // HttpException is reported without a stack trace, and so when it's
// wrapped twice it registers as a different exception each time (because
// it's given an ad-hoc stack trace). Always expect two exceptions when
@@ -166,16 +166,16 @@ void main() {
test('test 2', () {
// TODO(nweiz): There can be three errors due to issue 9151. The
- // HttpParserException is reported without a stack trace, and so when it's
+ // HttpException is reported without a stack trace, and so when it's
// wrapped twice it registers as a different exception each time (because
// it's given an ad-hoc stack trace). Always expect two exceptions when
@@ -199,16 +199,16 @@ void main() {
test('test 2', () {
// TODO(nweiz): There can be three errors due to issue 9151. The
- // HttpParserException is reported without a stack trace, and so when it's
+ // HttpException is reported without a stack trace, and so when it's
// wrapped twice it registers as a different exception each time (because
// it's given an ad-hoc stack trace). Always expect two exceptions when
@@ -304,16 +304,16 @@ void main() {
test('test 2', () {
// TODO(nweiz): There can be three errors due to issue 9151. The
- // HttpParserException is reported without a stack trace, and so when it's
+ // HttpException is reported without a stack trace, and so when it's
// wrapped twice it registers as a different exception each time (because
// it's given an ad-hoc stack trace). Always expect two exceptions when
@@ -336,15 +336,15 @@ void main() {
test('test 2', () {
// TODO(nweiz): There can be three errors due to issue 9151. The
- // HttpParserException is reported without a stack trace, and so when it's
+ // HttpException is reported without a stack trace, and so when it's
// wrapped twice it registers as a different exception each time (because
// it's given an ad-hoc stack trace). Always expect two exceptions when
« no previous file with comments | « pkg/scheduled_test/lib/src/scheduled_server/safe_http_server.dart ('k') | runtime/bin/dartutils.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698